@@ -234,11 +234,8 @@ guint    gconf_CORBA_Object_hash  (gconstpointer key);
 
 
 /* FIXME move to public eventually */
-GConfEntry* gconf_entry_copy (const GConfEntry *src);
 gboolean    gconf_entry_equal (const GConfEntry *a,
                                const GConfEntry *b);
-void        gconf_entry_ref   (GConfEntry *entry);
-void        gconf_entry_unref (GConfEntry *entry);
 int         gconf_value_compare (const GConfValue *value_a,
                                  const GConfValue *value_b);
 
